Changelog
=========

0.0.5
-----

- Add json error page configuration file

0.0.5
-----

- Add coverage

0.0.4
-----

- Clear dependency

0.0.3
-----

- Dumps nginx to files

0.0.2
-----

- Render conf with template

0.0.1
-----

- Initial public release
